==> profile_tool-2.0.1-py3-none-any.whl: profile_tool/config/readconfig.py <==
# Copyright 2019 IDaptive, LLC.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import configparser
import base64
from getpass import getpass
import logging
from . import proxy
from . import environment
from . import apps

def set_logging():
    logging.basicConfig(filename='config.log', level=logging.INFO)
    logging.info('Starting App..')
    
def read_proxy():
    file_reader = configparser.ConfigParser()
    config_file = 'proxy.properties'
    file_reader.read(config_file)
    isproxy = file_reader['Proxy']['proxy']
    http_proxy = file_reader['Proxy']['http_proxy']
    https_proxy = file_reader['Proxy']['https_proxy']
    proxy_user = file_reader['Proxy']['proxy_user']
    proxy_password = file_reader['Proxy']['proxy_password']
    proxy_object = proxy.Proxy(isproxy, http_proxy, https_proxy, proxy_user, proxy_password)
    return proxy_object
    
       
def log_config(proxy):
    proxy.log()
        
def read_config():
    proxy = read_proxy()
    log_config(proxy)
    return proxy

==> profile_tool-2.0.3-py3-none-any.whl: profile_tool/config/readconfig.py <==
# Copyright 2018 Centrify Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import configparser
import base64
from getpass import getpass
import logging
from . import proxy
from . import environment
from . import apps


def set_logging():
    logging.basicConfig(filename='config.log', level=logging.INFO)
    logging.info('Starting App..')


def read_proxy():
    file_reader = configparser.ConfigParser()
    config_file = 'proxy.properties'
    file_reader.read(config_file)
    isproxy = file_reader['Proxy']['proxy']
    http_proxy = file_reader['Proxy']['http_proxy']
    https_proxy = file_reader['Proxy']['https_proxy']
    proxy_user = file_reader['Proxy']['proxy_user']
    proxy_password = file_reader['Proxy']['proxy_password']
    proxy_object = proxy.Proxy(
        isproxy, http_proxy, https_proxy, proxy_user, proxy_password)
    return proxy_object


''' This method is not used
def read_environments():
    file_reader = configparser.ConfigParser()
    config_file = 'environment.properties'
    file_reader.read(config_file)
    sections = file_reader.sections()
    environments = []
    for section in sections:
        endpoint = file_reader[section]['endpoint']
        certpath = file_reader[section]['certpath']
        debug = file_reader[section]['debug']
        environment_object = environment.Environment(str(section), endpoint, certpath, debug)
        environments.append(environment_object)
    return environments
'''


def log_config(proxy):
    proxy.log()
#    for environment in environments:
#        environment.log()


def read_config():
    proxy = read_proxy()
#   environments = read_environments() No more needed
    log_config(proxy)
    return proxy
